/****************************************************************************
**
** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of the plugins module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QEVDEVTOUCH_P_H
#define QEVDEVTOUCH_P_H

#include <QObject>
#include <QString>
#include <QList>
#include <QThread>
#include <qpa/qwindowsysteminterface.h>

#if !defined(QT_NO_MTDEV)
struct mtdev;
#endif

QT_BEGIN_NAMESPACE

class QSocketNotifier;
class QEvdevTouchScreenData;

class QEvdevTouchScreenHandler : public QObject
{
    Q_OBJECT

public:
    explicit QEvdevTouchScreenHandler(const QString &specification = QString(), QObject *parent = 0);
    ~QEvdevTouchScreenHandler();

private slots:
    void readData();

private:
    QSocketNotifier *m_notify;
    int m_fd;
    QEvdevTouchScreenData *d;
#if !defined(QT_NO_MTDEV)
    mtdev *m_mtdev;
#endif
};

class QEvdevTouchScreenHandlerThread : public QThread
{
public:
    explicit QEvdevTouchScreenHandlerThread(const QString &spec, QObject *parent = 0);
    ~QEvdevTouchScreenHandlerThread();
    void run();
    QEvdevTouchScreenHandler *handler() { return m_handler; }

private:
    QString m_spec;
    QEvdevTouchScreenHandler *m_handler;
};

QT_END_NAMESPACE

#endif // QEVDEVTOUCH_P_H
